==> haskell-vector-instances-3.4.3-70.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-D9XsKYeactIB5mBFijznBE
key:                  vector-instances-3.4.3-D9XsKYeactIB5mBFijznBE
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  1b6c039d7b88dee62ad74903e06688c5
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-D9XsKYeactIB5mBFijznBE
depends:
    base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    keys-3.12.4-AkOg4ElzOjt7RzEpCwKgoO
    pointed-5.0.5-F62LVAgvv9AGSTClAwEX2m
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4.3-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-I7Qkh9V3qpNmvWkDy34LP
key:                  vector-instances-3.4.3-I7Qkh9V3qpNmvWkDy34LP
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  74f598144aa19dbab6f91be1601322ba
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-I7Qkh9V3qpNmvWkDy34LP
depends:
    base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    keys-3.12.4-EljU96GFctJFL9dLDzZVM0
    pointed-5.0.5-G4KDyoxPFVpBOfflLbnKHj
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
